@@ -7,7 +7,7 @@ sub skip_tests {
         do { eval "use EV"; $@ }
     );
     return "EV was not built with a kqueue backend"
-        if EV::backend() != BACKEND_KQUEUE();
+        if EV::backend() != EV::BACKEND_KQUEUE();
     return "wheel_readwrite test disabled for kqueue"
         if $_[0] eq 'wheel_readwrite';
     diag("Using EV with kqueue backend") if $_[0] eq '00_info';
